@@ -82,7 +82,7 @@ make_covmat<-function(design1,design2,subset){
 twophase2<-function(id,strata=NULL, probs=NULL, fpc=NULL,
                    subset, data){
 
-  d1<-svydesign(id=id[[1]],strata=strata[[1]],weights=NULL,
+  d1<-svydesign(ids=id[[1]],strata=strata[[1]],weights=NULL,
                 probs=probs[[1]],fpc=fpc[[1]],data=data)
 
   if(inherits(subset,"formula"))
@@ -93,7 +93,7 @@ twophase2<-function(id,strata=NULL, probs=NULL, fpc=NULL,
 
   if (any(is.na(subset))) stop("missing values in 'subset'")
   
-  d1s<-svydesign(id=id[[1]],strata=strata[[1]],weights=NULL,
+  d1s<-svydesign(ids=id[[1]],strata=strata[[1]],weights=NULL,
                 probs=probs[[1]],fpc=fpc[[1]],data=data[subset,])
   d1s$prob<-d1$prob[subset]
   d1s$allprob<-d1$allprob[subset,,drop=FALSE]
@@ -102,7 +102,7 @@ twophase2<-function(id,strata=NULL, probs=NULL, fpc=NULL,
   if (is.null(fpc[[2]])){
     complete.vars<-names(data)[apply(data, 2, function(v) all(!is.na(v)))]
     if (all(c(all.vars(id[[2]]), all.vars(strata[[2]])) %in% complete.vars)){
-      dfpc<-svydesign(id=id[[2]], strata=strata[[2]], data=data, probs=NULL)
+      dfpc<-svydesign(ids=id[[2]], strata=strata[[2]], data=data, probs=NULL)
       popsize<-mapply(function(s,i) ave(!duplicated(i),s,FUN=sum), dfpc$strata, dfpc$cluster)
       rm(dfpc)
     } else {
@@ -111,21 +111,21 @@ twophase2<-function(id,strata=NULL, probs=NULL, fpc=NULL,
     }
   } else popsize<-NULL
 
-  d2<-svydesign(id=id[[2]], strata=strata[[2]], probs=probs[[2]],
+  d2<-svydesign(ids=id[[2]], strata=strata[[2]], probs=probs[[2]],
                 weights=NULL, fpc=fpc[[2]], data=data[subset,])
 
   ## ugly hack to get nicer labels
   if(!is.null(fpc[[2]])){
-    d2call<-bquote(svydesign(id=.(id[[2]]),strata=.(strata[[2]]), probs=.(probs[[2]]),
+    d2call<-bquote(svydesign(ids=.(id[[2]]),strata=.(strata[[2]]), probs=.(probs[[2]]),
                                fpc=.(fpc[[2]])))
   } else{
-    d2call<-bquote(svydesign(id=.(id[[2]]),strata=.(strata[[2]]), probs=.(probs[[2]]),
+    d2call<-bquote(svydesign(ids=.(id[[2]]),strata=.(strata[[2]]), probs=.(probs[[2]]),
                                fpc=`*phase1*`))
   }
   for(i in names(d2call)[-1])
     d2call[[i]]<-d2call[[i]]
   d2$call<-d2call
-  d1call<-bquote(svydesign(id=.(id[[1]]), strata=.(strata[[1]]), probs=.(probs[[1]]),
+  d1call<-bquote(svydesign(ids=.(id[[1]]), strata=.(strata[[1]]), probs=.(probs[[1]]),
                                fpc=.(fpc[[1]])))
   for(i in names(d1call)[-1])
     d1call[[i]]<-d1call[[i]]
